<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => null,
    'favicon' => 'https://calendar.google.com/googlecalendar/images/favicons_2020q4/calendar_31.ico',
    'feeds' => [],
    'icon' => null,
    'image' => null,
    'keywords' => [],
    'language' => null,
    'languages' => [],
    'license' => null,
    'providerName' => 'Google',
    'providerUrl' => 'https://calendar.google.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Festivos en España',
    'url' => 'https://calendar.google.com/calendar/embed?src=spain__es%40holiday.calendar.google.com&ctz=Europe/Madrid',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
